# SOM CLI

###### A TUI that lets you vote on SOM projects via the terminal

## Features:
- Uses Textual for the TUI
- Uses Selenium and Beautiful Soup for web scraping
- Gets cookies from the user by asking for them

## Usage:
### pip (Recommended)
- Go into devtools in your browser while at summer.hackclub.com/campfire after signing in
- Go to the Storage tab
- In Cookies, there should be a cookie named _journey_session and copy the value of that cookie
- Then run `pip install SOM-TUI` in the terminal
- You might need to use `pip3 install SOM-TUI` on some systems
- Finally, type in `vote` in the terminal!
- Paste the cookie value you copied earlier into the text field
- Start voting!
- If you want to exit, tap Ctrl+Q